@@ -12,9 +12,9 @@
 
 #if defined(HAVE_MIGEMO_H)
 #include <migemo.h>
-migemo* gMigemo;
+static migemo* gMigemo;
 static regex_t* gReg;
-sObject* gMigemoCache; // 一文字だけの正規表現のクェリーは重いのでキャッシュする
+static sObject* gMigemoCache; // 一文字だけの正規表現のクェリーは重いのでキャッシュする
 #endif
 
 static sObject* gInputFileName;      // 入力された文字列
